@@ -2,22 +2,18 @@ use 5.012;
 use MooseX::Declare;
 use Method::Signatures::Modifiers;
 
-# PODNAME: Dist::Zilla::PluginBundle::BAREFOOT
-# PODNAME: Dist::Zilla::PluginBundle::BAREFOOT
 class Dist::Zilla::PluginBundle::BAREFOOT with Dist::Zilla::Role::PluginBundle::Easy
 {
-	use autodie										2.00					;
-	use PerlX::Maybe								0.003		'provided'	;
-	use List::MoreUtils											'uniq'		;
-	use MooseX::Has::Sugar													;
-	use MooseX::Types::Moose									':all'		;
-	use MooseX::ClassAttribute												;
+	use autodie										2.00				;
+	use List::MoreUtils											'uniq'	;
+	use MooseX::Has::Sugar												;
+	use MooseX::Types::Moose									':all'	;
 
 	# Dependencies
 	use Dist::Zilla									4.3			  ;		# authordeps
 
-	# supplies: Git::Check, Git::Commit, Git::NextVersion, Git::Push, Git::Tag
-	use Dist::Zilla::PluginBundle::Git				2.013		();
+	use Dist::Zilla::PluginBundle::Git							();
+	#use Dist::Zilla::PluginBundle::Filter						();
 
 	use Dist::Zilla::Plugin::PodWeaver							();
 	use Dist::Zilla::Plugin::GithubMeta				0.10		();
@@ -29,24 +25,18 @@ class Dist::Zilla::PluginBundle::BAREFOOT with Dist::Zilla::Role::PluginBundle::
 	use Dist::Zilla::Plugin::Test::Version						();
 	use Dist::Zilla::Plugin::CheckExtraTests					();
 	use Dist::Zilla::Plugin::InsertCopyright		0.001		();
+	use Dist::Zilla::Plugin::Git::NextVersion					();
 	use Dist::Zilla::Plugin::ReadmeAnyFromPod		0.120051	();
 	use Dist::Zilla::Plugin::Test::PodSpelling		2.001002	();
 	use Dist::Zilla::Plugin::CopyFilesFromBuild					();
 	use Dist::Zilla::Plugin::CheckPrereqsIndexed	0.002		();
-	use Dist::Zilla::Plugin::CheckVersionIncrement	0.121750	();
-	use Dist::Zilla::Plugin::MetaProvides::Package	1.14		();		# hides DB/main/private packages
-	use Dist::Zilla::Plugin::MetaProvides::Class	2.001		();		# adds 'provides' to META.* for `class`
-	use Dist::Zilla::Plugin::PodnameFromClassname	0.1100		();		# stops Pod::Weaver from complaining
+	#use Dist::Zilla::Plugin::MetaProvides::Package	1.14		();		# hides DB/main/private packages
 	use Dist::Zilla::Plugin::CheckChangesHasContent				();
 
 
-	our $VERSION = '0.06_02'; # TRIAL VERSION
+	our $VERSION = '0.01'; # VERSION
 
-	my @dirty_files = qw< dist.ini Changes >;
-	my @exclude_generated_files = qw< README.pod META.json >;
-
-	class_has weaver_payload	=>	( ro, writer => '_store_weaver_data', isa => HashRef, lazy,
-											default => sub { die "class attribute weaver_payload called too soon!" }, );
+	my @dirty_files = qw< dist.ini Changes README.pod >;
 
 
 	sub mvp_multivalue_args { qw/stopwords/ }
@@ -57,6 +47,7 @@ class Dist::Zilla::PluginBundle::BAREFOOT with Dist::Zilla::Role::PluginBundle::
 	has auto_prereq		=>	( ro, isa => Bool, lazy, default => method { $self->payload->{'auto_prereq'} // 1 } );
 	has tag_format		=>	( ro, isa => Str, lazy, default => method { $self->payload->{'tag_format'} // 'v%v' } );
 	has version_regexp	=>	( ro, isa => Str, lazy, default => method { $self->payload->{'version_regexp'} // '^v(.+)$' } );
+	has weaver_config	=>	( ro, isa => Str, lazy, default => method { $self->payload->{'weaver_config'} // '@BAREFOOT' } );
 	has git_remote		=>	( ro, isa => Str, lazy, default => method { $self->payload->{'git_remote'} // 'origin' } );
 	has legal_addendum	=>	( ro, isa => Str, lazy, default => method { $self->payload->{'legal_addendum'} // '' } );
 
@@ -68,23 +59,20 @@ class Dist::Zilla::PluginBundle::BAREFOOT with Dist::Zilla::Role::PluginBundle::
 		$self->add_plugins (
 
 			# version number
-			#[ 'Git::NextVersion'		=>	{ first_version => '0.01', version_regexp => $self->version_regexp } ],
+			[ 'Git::NextVersion'		=>	{ first_version => '0.01', version_regexp => $self->version_regexp } ],
 
 			# gather and prune
-			[ GatherDir					=>	{ exclude_filename => [@exclude_generated_files] }],# core
-			#PruneCruft					=>														# core
-			#ManifestSkip				=>														# core
+			[ GatherDir					=>	{ exclude_filename => [qw< README.pod >] }],		# core
+			PruneCruft					=>														# core
+			ManifestSkip				=>														# core
 
-provided $self->auto_prereq,
-			[ AutoPrereqs				=>	{ skip => "^t::lib" } ],
-			#
 			# file munging
 			OurPkgVersion				=>
-			PodnameFromClassname		=>
-			#InsertCopyright				=>
-			[ PodWeaver					=>	{ config_plugin => '@BAREFOOT', } ],
+			InsertCopyright				=>
+			[ PodWeaver					=>	{ config_plugin => $self->weaver_config } ],
 
 			# generated distribution files
+			ReadmeFromPod				=>
 			License						=>														# core
 			[ ReadmeAnyFromPod			=>	{	# generate in root for github, etc.
 												type		=> 'pod',
@@ -92,26 +80,32 @@ provided $self->auto_prereq,
 												location	=> 'root',
 											}
 			],
-			[ Bugtracker				=>	{ web => 'http://github.com/barefootcoder/%l/issues' } ],
 
-#			# generated xt/ tests
-#provided not $self->no_spellcheck,
-#			[ 'Test::PodSpelling'		=>	{ stopwords => $self->stopwords } ],
-#			MetaTests					=>														# core
+			# generated xt/ tests
+		( $self->no_spellcheck
+		?	()
+		:	[ 'Test::PodSpelling'		=>	{ stopwords => $self->stopwords } ]
+		),
+			MetaTests					=>														# core
 			PodSyntaxTests				=>														# core
 			PodCoverageTests			=>														# core
-#			'Test::Version'				=>
+			'Test::Version'				=>
 
 			# metadata
-			#MinimumPerl					=>
+			MinimumPerl					=>
+		( $self->auto_prereq
+		?	[ AutoPrereqs				=>	{ skip => "^t::lib" } ]
+		:	()
+		),
 			[ GithubMeta				=>	{ remote => $self->git_remote } ],
-			#[ MetaNoIndex				=>	{
-			#									directory	=> [qw< t xt examples corpus >],
-			#									package		=> [qw< DB >]
-			#								}
-			#],
-			[ 'MetaProvides::Class'		=>	{ inherit_version => 1 } ],							# AFTER MetaNoIndex
-			#MetaYAML					=>														# core
+			[ MetaNoIndex				=>	{
+												directory	=> [qw< t xt examples corpus >],
+												package		=> [qw< DB >]
+											}
+			],
+			#[ 'MetaProvides::Package'	=>	{ meta_noindex => 1 } ],							# AFTER MetaNoIndex
+			[ Bugtracker				=>	{ web => "http://github.com/me/%l/issues" } ],
+			MetaYAML					=>														# core
 			MetaJSON					=>														# core
 
 			# build system
@@ -119,37 +113,36 @@ provided $self->auto_prereq,
 			ShareDir					=>														# core
 			MakeMaker					=>														# core
 
+			# copy files from build back to root for inclusion in VCS
+			[ CopyFilesFromBuild		=>	{
+												move => 'README.pod',
+											}
+			],
+
 			# manifest -- must come after all generated files
 			Manifest					=>														# core
 
 			# before release
 			[ 'Git::Check'				=>	{
-												allow_dirty	=> [@dirty_files, @exclude_generated_files]
+												allow_dirty	=> [@dirty_files]
 											}
 			],
-			CheckVersionIncrement		=>
-			#CheckPrereqsIndexed			=>
+			CheckPrereqsIndexed			=>
 			CheckChangesHasContent		=>
 			CheckExtraTests				=>
 			TestRelease					=>														# core
 			ConfirmRelease				=>														# core
 
 			# release
-$self->fake_release
+		( $self->fake_release
 		?	'FakeRelease'
-		:	'UploadToCPAN',																		# core
+		:	'UploadToCPAN'																		# core
+		),
 
 			# after release
 			# Note -- NextRelease is here to get the ordering right with
-			# git actions.  It is *also* a file munger that acts earlier.
+			# git actions.  It is *also* a file munger that acts earlier
 
-			[ 'Git::Tag'				=>	{
-												tag_format	=> $self->tag_format,
-												tag_message	=> 'version %v for CPAN',
-											}
-			],
-			# bumps Changes
-			NextRelease					=>														# core (also munges files)
 			# commit dirty Changes, dist.ini, README.pod
 			[ 'Git::Commit'				=>
 											{
@@ -157,14 +150,19 @@ $self->fake_release
 												commit_msg	=> "packaging for CPAN: %v",
 											}
 			],
+			[ 'Git::Tag'				=>	{
+												tag_format	=> $self->tag_format,
+												tag_message	=> 'version %v for CPAN',
+											}
+			],
+
+			# bumps Changes
+			NextRelease					=>														# core (also munges files)
 
 			[ 'Git::Push'				=>	{ push_to => [@push_to] } ],
 
 		);
 
-		my @weaver_params = qw< repository_link >;
-		$self->_store_weaver_data({ map { $_ => $self->payload->{$_} } @weaver_params });
-
 	}
 
 }
@@ -174,7 +172,7 @@ $self->fake_release
 # ABSTRACT: Dist::Zilla configuration the way BAREFOOT does it
 # COPYRIGHT
 
-__END__
+
 
 =pod
 
@@ -184,7 +182,7 @@ Dist::Zilla::PluginBundle::BAREFOOT - Dist::Zilla configuration the way BAREFOOT
 
 =head1 VERSION
 
-This document describes version 0.06_02 of Dist::Zilla::PluginBundle::BAREFOOT.
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -196,64 +194,63 @@ This document describes version 0.06_02 of Dist::Zilla::PluginBundle::BAREFOOT.
 This is a L<Dist::Zilla> PluginBundle.  It is roughly equivalent to the following dist.ini:
 
  	; version provider
- 	; hopefully soemething here soon
+ 	[Git::NextVersion]					; get version from last release tag
+ 	first_version = 0.01
+ 	version_regexp = ^v(.+)$
  
  	; choose files to include
  	[GatherDir]							; everything under top dir
  	exclude_filename = README.pod		; skip this generated file
  	exclude_filename = META.json		; skip this generated file
  
- 	;[PruneCruft]						; default stuff to skip
- 	;[ManifestSkip]						; if -f MANIFEST.SKIP, skip those, too
- 
- 	; this should probably be moved to metadata section
- 	[AutoPrereqs]						; find prereqs from code
- 	skip = ^t::lib
+ 	[PruneCruft]						; default stuff to skip
+ 	[ManifestSkip]						; if -f MANIFEST.SKIP, skip those, too
  
  	; file modifications
  	[OurPkgVersion]						; add $VERSION = ... to all files
- 	;[InsertCopyright					; add copyright at "# COPYRIGHT"
+ 	[InsertCopyright					; add copyright at "# COPYRIGHT"
  	[PodWeaver]							; generate Pod
  	config_plugin = @BAREFOOT			; allows Pod::WikiDoc and a few other bits and bobs
  
  	; generated files
  	[License]							; boilerplate license
+ 	[ReadmeFromPod]						; from Pod (runs after PodWeaver)
  	[ReadmeAnyFromPod]					; create README.pod in repo directory
  	type = pod
  	filename = README.pod
  	location = root
  
- 	; should this be in metadata section?
- 	[Bugtracker]
- 	web = http://github.com/barefootcoder/%l/issues
- 
  	; xt tests
- 	;[Test::PodSpelling]					; xt/author/pod-spell.t
- 	;[MetaTests]							; xt/release/meta-yaml.t
- 	;[PodSyntaxTests]					; xt/release/pod-syntax.t
- 	;[PodCoverageTests]					; xt/release/pod-coverage.t
- 	;[Test::Version]						; xt/release/test-version.t
+ 	[Test::PodSpelling]					; xt/author/pod-spell.t
+ 	[MetaTests]							; xt/release/meta-yaml.t
+ 	[PodSyntaxTests]					; xt/release/pod-syntax.t
+ 	[PodCoverageTests]					; xt/release/pod-coverage.t
+ 	[Test::Version]						; xt/release/test-version.t
  
  	; metadata
- 	;[MinimumPerl]						; determine minimum perl version
+ 	[AutoPrereqs]						; find prereqs from code
+ 	skip = ^t::lib
+ 
+ 	[MinimumPerl]						; determine minimum perl version
  	[GithubMeta]
  	remote = origin
  
- 	;[MetaYAML]							; generate META.yml (v1.4)
- 	[MetaJSON]							; generate META.json (v2)
+ 	[MetaNoIndex]						; sets 'no_index' in META
+ 	directory = t
+ 	directory = xt
+ 	directory = examples
+ 	directory = corpus
+ 	package = DB						; just in case
  
- 	;[MetaNoIndex]						; sets 'no_index' in META
- 	;directory = t
- 	;directory = xt
- 	;directory = examples
- 	;directory = corpus
- 	;package = DB						; just in case
+ 	[Bugtracker]
+ 	web = http://github.com/me/%l/issues
  
  	; can't get this one to work right ATM
  	; [MetaProvides::Package]			; add 'provides' to META files
  	; meta_noindex = 1					; respect prior no_index directives
- 	[MetaProvides::Class]				; add 'provides' to META files for classes
- 	inherit_version = 1 				; use version from dist.ini
+ 
+ 	[MetaYAML]							; generate META.yml (v1.4)
+ 	[MetaJSON]							; generate META.json (v2)
  
  	; build system
  	[ExecDir]							; include 'bin/*' as executables
@@ -263,15 +260,18 @@ This is a L<Dist::Zilla> PluginBundle.  It is roughly equivalent to the followin
  	; manifest (after all generated files)
  	[Manifest]							; create MANIFEST
  
+ 	; move README.pod back to repo dir
+ 	[CopyFilesFromBuild]
+ 	move = README.pod
+ 
  	; before release
  	[Git::Check]						; ensure all files checked in
  	allow_dirty = dist.ini
  	allow_dirty = Changes
- 	allow_dirty = README.pod			; ignore this generated file
- 	allow_dirty = META.json				; ignore this generated file
+ 	allow_dirty = README.pod
+ 	allow_dirty = META.json
  
- 	;[CheckPrereqsIndexed]				; ensure prereqs are on CPAN
- 	[CheckVersionIncrement]				; ensure version has been bumped
+ 	[CheckPrereqsIndexed]				; ensure prereqs are on CPAN
  	[CheckChangesHasContent]			; ensure Changes has been updated
  	[CheckExtraTests]					; ensure xt/ tests pass
  	[TestRelease]						; ensure t/ tests pass
@@ -281,18 +281,20 @@ This is a L<Dist::Zilla> PluginBundle.  It is roughly equivalent to the followin
  	[UploadToCPAN]						; uploads to CPAN
  
  	; after release
+ 	[Git::Commit / Commit_Dirty_Files]	; commit Changes (as released)
+ 
  	[Git::Tag]							; tag repo with custom tag
  	tag_format = v%v					; this one is overridable
  	tag_message = version %v for CPAN	; this one isn't
  
  	; NextRelease acts *during* pre-release to write $VERSION and
  	; timestamp to Changes and  *after* release to add a new {{$NEXT}}
- 	; section, so to act at the right time after release, it must come
- 	; after UploadToCPAN but before Git::Commit in the dist.ini.  It
- 	; will still act during pre-release as usual.
+ 	; section, so to act at the right time after release, it must actually
+ 	; come after Commit_Dirty_Files but before Commit_Changes in the
+ 	; dist.ini.  It will still act during pre-release as usual
  	[NextRelease]
  
- 	[Git::Commit]						; commit Changes (for new dev)
+ 	[Git::Commit / Commit_Changes]		; commit Changes (for new dev)
  
  	[Git::Push]							; push repo to remote
  	push_to = origin
@@ -336,16 +338,16 @@ risking a real release.
 
 =item *
 
+C<<< weaver_config >>> -- Specifies a Pod::Weaver bundle.  Defaults to @BAREFOOT.
+
+=item *
+
 C<<< stopwords >>> -- Add stopword for Test::PodSpelling (can be repeated).
 
 =item *
 
 C<<< no_spellcheck >>> -- Omit Test::PodSpelling tests.
 
-=item *
-
-C<<< repository_link >>> -- Override the Pod::Weaver L<Support> section default (which is "both").
-
 =back
 
 =head1 INSTALLATION
@@ -369,6 +371,18 @@ L<Dist::Zilla::Plugin::PodWeaver>
 
 =back
 
+=head1 AUTHOR
+
+Buddy Burden <barefoot@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Buddy Burden.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
+
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
@@ -381,30 +395,11 @@ You can find documentation for this module with the perldoc command.
 
 =head2 Bugs / Feature Requests
 
-This module is on GitHub.  Feel free to fork and submit patches.  Please note that I develop
-via TDD (Test-Driven Development), so a patch that includes a failing test is much more
-likely to get accepted (or at least likely to get accepted more quickly).
-
-If you just want to report a problem or suggest a feature, that's okay too.  You can create
-an issue on GitHub here: L<http://github.com/barefootcoder/dist-zilla-pluginbundle-barefoot/issues>.
-
-=head2 Source Code
-
 none
-L<https://github.com/barefootcoder/dist-zilla-pluginbundle-barefoot>
-
-  git clone https://github.com/barefootcoder/dist-zilla-pluginbundle-barefoot.git
-
-=head1 AUTHOR
-
-Buddy Burden <barefoot@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2020 by Buddy Burden.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
+
+__END__
+
+
