@@ -1,14 +1,8 @@
-use 5.012;
-use MooseX::Declare;
-use Method::Signatures::Modifiers;
+use strict;
+use warnings;
 
-# PODNAME: Pod::Weaver::PluginBundle::BAREFOOT
-# PODNAME: Pod::Weaver::PluginBundle::BAREFOOT
-class Pod::Weaver::PluginBundle::BAREFOOT
 {
-	use autodie										2.00				;
-	use MooseX::Has::Sugar												;
-	use MooseX::Types::Moose									':all'	;
+	package Pod::Weaver::PluginBundle::BAREFOOT;
 
 	# Dependencies
 	use Pod::Weaver 3.101635; # fixed ABSTRACT scanning
@@ -19,33 +13,25 @@ class Pod::Weaver::PluginBundle::BAREFOOT
 	use Pod::Weaver::Section::Support 1.001 ();
 
 
-	our $VERSION = '0.06_02'; # TRIAL VERSION
+	our $VERSION = '0.01'; # VERSION
 
-
-	my $bugtracker_content = <<'END' =~ s/^\h+//mgr;
+	my $bugtracker_content = <<'END';
 		This module is on GitHub.  Feel free to fork and submit patches.  Please note that I develop
 		via TDD (Test-Driven Development), so a patch that includes a failing test is much more
-		likely to get accepted (or at least likely to get accepted more quickly).
+		likely to get accepted (or least likely to get accepted more quickly).
 
 		If you just want to report a problem or suggest a feature, that's okay too.  You can create
 		an issue on GitHub here: {WEB}.
 END
 
 
-	method _exp { Pod::Weaver::Config::Assembler->expand_package($self) }
+	sub _exp { Pod::Weaver::Config::Assembler->expand_package($_[0]) }
 
-	method mvp_bundle_config ($class: ...)
+	sub mvp_bundle_config
 	{
-		# get payload (configurable parameters) from the dzil plugin bundle
-		my $payload = Dist::Zilla::PluginBundle::BAREFOOT->weaver_payload;
-
-		# now set default values for them
-		$payload->{'repository_link'}	//= 'both';
-
 		my @plugins;
 		push @plugins, (
 			[ '@BAREFOOT/WikiDoc',     _exp('-WikiDoc'),	{} ],
-
 			[ '@BAREFOOT/CorePrep',    _exp('@CorePrep'),	{} ],
 			[ '@BAREFOOT/Name',        _exp('Name'),		{} ],
 			[ '@BAREFOOT/Version',     _exp('Version'),		{
@@ -53,15 +39,16 @@ END
 															}
 			],
 
+			#[ '@BAREFOOT/Prelude',     _exp('Region'),		{ region_name => 'prelude'     } ],
 			[ '@BAREFOOT/Synopsis',    _exp('Generic'),		{ header      => 'SYNOPSIS'    } ],
 			[ '@BAREFOOT/Description', _exp('Generic'),		{ header      => 'DESCRIPTION' } ],
 			[ '@BAREFOOT/Overview',    _exp('Generic'),		{ header      => 'OVERVIEW'    } ],
 		);
 
 		for my $plugin (
-			[ 'Attributes', 			_exp('Collect'),	{ command => 'attr'   } ],
-			[ 'Methods',    			_exp('Collect'),	{ command => 'method' } ],
-			[ 'Functions',  			_exp('Collect'),	{ command => 'func'   } ],
+			[ 'Attributes', _exp('Collect'),				{ command => 'attr'   } ],
+			[ 'Methods',    _exp('Collect'),				{ command => 'method' } ],
+			[ 'Functions',  _exp('Collect'),				{ command => 'func'   } ],
 		){
 			$plugin->[2]->{'header'} = uc $plugin->[0];
 			push @plugins, $plugin;
@@ -74,7 +61,7 @@ END
 																websites			=> 'none',
 																bugs				=> 'metadata',
 																bugs_content		=> $bugtracker_content,
-																repository_link		=> $payload->{'repository_link'},
+																repository_link		=> 'both',
 																repository_content	=> 'none',
 															}
 			],
@@ -93,8 +80,8 @@ END
 
 1;
 
-__END__
 
+__END__
 =pod
 
 =head1 NAME
@@ -103,7 +90,7 @@ Pod::Weaver::PluginBundle::BAREFOOT - BAREFOOT's default Pod::Weaver config
 
 =head1 VERSION
 
-This document describes version 0.06_02 of Pod::Weaver::PluginBundle::BAREFOOT.
+version 0.01
 
 =head1 DESCRIPTION
 
@@ -112,35 +99,14 @@ following weaver.ini:
 
    [-WikiDoc]
  
-   [@CorePrep]
+   [@Default]
  
-   [Name]
-   [Version]
- 
-   [Generic / SYNOPSIS]
-   [Generic / DESCRIPTION]
-   [Generic / OVERVIEW]
- 
-   [Collect / ATTRIBUTES]
-   command = attr
- 
-   [Collect / METHODS]
-   command = method
- 
-   [Collect / FUNCTIONS]
-   command = func
- 
-   [Leftovers]
    [Support]
    perldoc = 1
    websites = none
    bugs = metadata
    bugs_content = ... stuff (web only, email omitted) ...
-   repository_link = both
-   repository_content = none
- 
-   [Authors]
-   [Legal]
+   repository_link = none
  
    [-Transformer]
    transfomer = List
@@ -180,10 +146,11 @@ Buddy Burden <barefoot@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2020 by Buddy Burden.
+This software is Copyright (c) 2012 by Buddy Burden.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
